pub struct StringFromEnvVar {
pub from_env_var: Option<String>,
pub value: Option<String>,
}Expand description
Either an env var or a string literal. TODO: From Prisma 7 onwards, this struct will not be needed, as the value will always be a plain String.
Fields
from_env_var: Option<String>Contains the name of env var if the value was read from one.
value: Option<String>Contains the string literal, when it was directly in the parsed schema.
Implementations
Sourceimpl StringFromEnvVar
impl StringFromEnvVar
pub fn new_from_env_var(env_var_name: String) -> StringFromEnvVar
pub fn new_literal(value: String) -> StringFromEnvVar
Sourcepub fn as_env_var(&self) -> Option<&str>
pub fn as_env_var(&self) -> Option<&str>
Returns the name of the env var, if env var.
Sourcepub fn as_literal(&self) -> Option<&str>
pub fn as_literal(&self) -> Option<&str>
Returns the contents of the string literal, if applicable.